require 'json'
require 'sinatra'
require 'yaml'
require File.expand_path(File.dirname(__FILE__) + "/lib/rrd_repo")

configure :production do
  set :port, 5678
end

get '/ping' do
  'pong'
end

get '/data/:file/latest/sum' do |file|
  unless _allowed_rrds.has_key?(file)
    return 404
  end

  filename = _allowed_rrds[file]
  rrd_repo = RRDRepo.new(filename)
  rrd_repo.latest_value("sum").to_s
end

get '/data/:file/read/' do |file|
  unless _allowed_rrds.has_key?(file)
    return 404
  end

  if params[:resolution].nil?
    status 400
    body "You must provide a 'resolution' query param in seconds"
    return
  end

  if params[:duration].nil?
    status 400
    body "You must provide a 'duration' query param in seconds"
    return
  end

  filename = _allowed_rrds[file]
  rrd_repo = RRDRepo.new(filename)
  info = rrd_repo.info
  response.headers["X-RRD"] = "step=#{info[:step]}"
  info[:archives].each_with_index do |archive, i|
    response.headers["X-RRD-Archive#{i}"] = "cf=#{archive[:consolidation_function]}; resolution=#{archive[:resolution_sec]}; duration=#{archive[:duration_sec]}"
  end

  res = params[:resolution].to_i
  dur = params[:duration].to_i
  stop = Time.now
  start = stop - dur
  JSON.dump(rrd_repo.read(res, start, stop))
end

def _allowed_rrds
  config_file = [
    ENV["RACK_ENV"],
    "/etc/rrd_rest_api/allowed_rrds.yml",
    File.expand_path(File.dirname(__FILE__)) + "/allowed_rrds.yml",
    File.expand_path(File.dirname(__FILE__)) + "/allowed_rrds.yml.example"
  ].compact.select {|filename| File.exist?(filename)}.first


  @allowed_rrds ||= YAML.load_file(config_file)
end
